# Bug Reports

If you find <font color=pink>Geochemistry Py</font> does not work well with you, in the meantime, googling error messages cannot help. Please check the Q&A first to see if similar questions have already been posted, and there may already be valid comments. If not, please contact us and send the details of bug. Our experts are willing to solve the problems for you as soon as we can. Here is a toturial posted on Youtube [“Geochemistry π-How to use Github for collaboration and Bug reporting-Sany”](https://www.youtube.com/watch?v=1DWoEsqsfvQ&list=PLy8hNsI55lvh1UHjhVhqNUj3xPdV9sEiM&index=4).

**Ways to report other bugs** (downloading or running the software):

1. Contact Sany (Email: sanyhew1097618435@163.com) with the title as "Bug: Geochemistry Pi".
2. Open our GitHub issue (channel: ZJUEarthData) and follow the [template](https://github.com/ZJUEarthData/geochemistrypi/issues/26) to detail the problem.
